package com.gic.enterprise.service.outer.impl;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.dto.data.DataActuallyPaidConfigDTO;
import com.gic.enterprise.dto.data.DataMemberConsumeConfigDTO;
import com.gic.enterprise.entity.TabDataActuallyPaidConfig;
import com.gic.enterprise.entity.TabDataMemberConsumeConfig;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.DataActuallyPaidConfigService;
import com.gic.enterprise.service.DataConfigApiService;
import com.gic.enterprise.service.DataMemberConsumeConfigService;
import com.gic.enterprise.service.DataWechatMemberConfigService;

@Service("dataConfigApiService")
public class DataConfigApiServiceImpl implements DataConfigApiService {
    @Autowired
    private DataMemberConsumeConfigService dataMemberConsumeConfigService;
    @Autowired
    private DataWechatMemberConfigService dataWechatMemberConfigService;
    @Autowired
    private DataActuallyPaidConfigService dataActuallyPaidConfigService;

    @Override
    public ServiceResponse<Integer> configMemberConsume(DataMemberConsumeConfigDTO dto) {
        if (dto.getEnterpriseId() == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID不能为空");
        }
        TabDataMemberConsumeConfig record = dataMemberConsumeConfigService.getByEnterpriseId(dto.getEnterpriseId());
        if (record == null) {
            //还未配置，新增
            return ServiceResponse.success(dataMemberConsumeConfigService.saveMemberConsumeConfig(dto));
        }
        dto.setMemberConsumeConfigId(record.getMemberConsumeConfigId());
        dataMemberConsumeConfigService.editMemberConsumeConfig(dto);
        return ServiceResponse.success(record.getMemberConsumeConfigId());
    }

    @Override
    public ServiceResponse<DataMemberConsumeConfigDTO> getMemberConsumeConfigByEnterpriseId(Integer enterpriseId) {
        TabDataMemberConsumeConfig record = dataMemberConsumeConfigService.getByEnterpriseId(enterpriseId);
        if (record == null) {
            //还未配置，新增
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "还未配置会员消费规则");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(DataMemberConsumeConfigDTO.class, record));
    }

    @Override
    public ServiceResponse<Void> configActuallyPaid(List<DataActuallyPaidConfigDTO> dtoList) {
        if (CollectionUtils.isEmpty(dtoList)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "实付配置内容为空");
        }
        for (DataActuallyPaidConfigDTO dto : dtoList) {
            if (dto.getClassify() == null) {
                dto.setClassify(1);
            }
            dataActuallyPaidConfigService.delete(dto.getEnterpriseId(), dto.getClassify());
            dto.setConfigStatus(Optional.ofNullable(dto.getConfigStatus()).orElse(0));
            dataActuallyPaidConfigService.saveActuallyPaidConfig(dto);
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<DataActuallyPaidConfigDTO>> listActuallyPaidConfig(Integer enterpriseId) {
        List<TabDataActuallyPaidConfig> list = dataActuallyPaidConfigService.listByEnterpriseId(enterpriseId);
        if (CollectionUtils.isEmpty(list)) {
            //如果没有配置，默认数据
            return ServiceResponse.success(EntityUtil.changeEntityListNew(DataActuallyPaidConfigDTO.class,
                    dataActuallyPaidConfigService.listByEnterpriseId(-1)));
        }
        return ServiceResponse.success(EntityUtil.changeEntityListNew(DataActuallyPaidConfigDTO.class, list));
    }

    @Override
    public ServiceResponse<Void> initActuallyPaidData(Integer enterpriseId) {
        List<TabDataActuallyPaidConfig> list = dataActuallyPaidConfigService.listByEnterpriseId(-1);
        list = list
                .stream()
                .map(e -> e.setEnterpriseId(enterpriseId))
                .map(e -> e.setActuallyPaidConfigId(null))
                .collect(Collectors.toList());
        configActuallyPaid(EntityUtil.changeEntityListNew(DataActuallyPaidConfigDTO.class, list));
        return ServiceResponse.success();
    }
}
