package com.gic.enterprise.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.commons.util.StringUtil;
import com.gic.enterprise.dto.data.DataActuallyPaidConfigDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.web.vo.data.ActuallyPaidConfigVO;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.OperationResultUtils;
import com.gic.enterprise.dto.data.DataMemberConsumeConfigDTO;
import com.gic.enterprise.service.DataConfigApiService;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;

import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/data-config")
public class DataConfigController {
    private final static Logger LOGGER = LogManager.getLogger(DataConfigController.class);

    @Autowired
    private DataConfigApiService dataConfigApiService;

    @RequestMapping("/config-member-consume")
    public RestResponse configMemberConsume(DataMemberConsumeConfigDTO dto) {
        dto.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        return OperationResultUtils.operationResult(dataConfigApiService.configMemberConsume(dto),
                OperationResultUtils.LOG_EDIT + "数据统计配置-会员消费配置",
                UserDetailUtils.getUserDetail().getEnterpriseInfo().getEnterpriseName());
    }

    @RequestMapping("/get-member-consume-config")
    public RestResponse getMemberConsumeConfig() {
        return ResultControllerUtils.commonResult(dataConfigApiService
                .getMemberConsumeConfigByEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId()));
    }

    @RequestMapping("/config-actually-paid")
    public RestResponse configActuallyPaid(String jsonArr) {
        if (StringUtil.isBlank(jsonArr)) {
            return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "实付配置内容为空");
        }
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        List<DataActuallyPaidConfigDTO> dtoList = JSON.parseArray(jsonArr, DataActuallyPaidConfigDTO.class);
        dtoList = dtoList
                .stream()
                .map(e -> e.setEnterpriseId(enterpriseId))
                .collect(Collectors.toList());
        return OperationResultUtils.operationResult(dataConfigApiService.configActuallyPaid(dtoList),
                OperationResultUtils.LOG_EDIT + "数据统计配置-实付配置",
                UserDetailUtils.getUserDetail().getEnterpriseInfo().getEnterpriseName());
    }

    @RequestMapping("/get-actually-paid-config")
    public RestResponse getActuallyPaidConfig() {
        return ResultControllerUtils.commonResult(dataConfigApiService
                .listActuallyPaidConfig(UserDetailUtils.getUserDetail().getEnterpriseId()), ActuallyPaidConfigVO.class);
    }
}
